var API_URL = 'https://www.climblife.us';
// var API_URL = 'http://localhost:3000';
var getToken = function() { return window.localStorage['authToken'];};

function b64toBlob(b64Data, contentType, sliceSize) {
  contentType = contentType || '';
  sliceSize = sliceSize || 512;

  var byteCharacters = atob(b64Data);
  var byteArrays = [];

  for (var offset = 0; offset < byteCharacters.length; offset += sliceSize) {
    var slice = byteCharacters.slice(offset, offset + sliceSize);

    var byteNumbers = new Array(slice.length);
    for (var i = 0; i < slice.length; i++) {
      byteNumbers[i] = slice.charCodeAt(i);
    }

    var byteArray = new Uint8Array(byteNumbers);

    byteArrays.push(byteArray);
  }

  var blob = new Blob(byteArrays, {type: contentType});
  return blob;
}

angular.module('climblife.services', [])
.factory('TripService', function($http, $cordovaGeolocation) {
  var getLocation = function(callback) {
    ionic.Platform.ready(function(){
      var posOptions = {timeout: 10000};
      $cordovaGeolocation.getCurrentPosition(posOptions)
        .then(function (position) {
          callback(null, position.coords);
        }, function(err) {
          callback(err || 'Unable to retrieve your location');
        });
    });
  };

  var token = window.localStorage['authToken'];
  var methods = {
    allUserTrips: function(callback) {
      $http({
        url: API_URL + '/all-user-trips.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    getTrips: function(params, callback) {
      params = params || {};
      if (params.range > 0 || params.isMap) {
        getLocation(function(error, coords) {
          if (error) return callback(error);
          params.lat = coords.latitude;
          params.lng = coords.longitude;

          methods._doGetTrips(params, callback);
        });
      } else {
        methods._doGetTrips(params, callback);
      }
    },
    _doGetTrips: function(params, callback) {
      $http({
        url: API_URL + ((params.from && params.to) ? '/mobile-trips.json' : '/mobile-upcoming-trips.json'),
        method: 'GET',
        params: {
          p: getToken(),
          start_date: params.from ? new Date(params.from) : undefined,
          end_date: params.to ? new Date(params.to) : undefined,
          climbing_type: params.type,
          current_lat: params.range ? params.lat : undefined,
          current_lon: params.range ? params.lng : undefined,
          from_location: params.range
        }
      }).success(function(response) {
        callback(null, response, {lat: params.lat, lng: params.lng});
      }).error(function(error) {
        callback(error);
      });
    },

    getTrip: function(id, callback) {
      $http({
        url: API_URL + '/mobile-trip.json',
        method: "GET",
        params: {p: getToken(), id: id}
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    betweenDates: function(startDate, endDate, params, callback) {
      params = params || {};
      $http({
        url: API_URL + '/mobile-trips.json',
        method: 'GET',
        params: {
          p: getToken(),
          start_date: startDate,
          end_date: endDate,
          climbing_type: params.type,
          current_lat: params.lat,
          current_lon: params.lng,
          from_location: params.range
        }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    getTripDestroy: function(trip_id, callback) {
      $http({
        url: API_URL + '/mobile-trip-user-destroy.json',
        method: 'GET',
        params: {p: getToken(), trip_id: trip_id}
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    deleteTrip: function(id, callback) {
      $http({
        url: API_URL + '/mobile-user-trips.json',
        method: 'DELETE',
        params: { p: getToken(), trip_id: id }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    }
  }
  return methods;
})

.factory('TripConfirmationService', function($http) {
  var token = window.localStorage['authToken'];
  var methods = {
    getTrip: function(id, callback) {
      $http({
        url: API_URL + '/mobile-trip-confirmation.json',
        method: 'GET',
        params: { p: getToken(), trip_confirmation_id: id }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    bookTrip: function(trip_id, stripeToken, stripeEmail, callback) {
      $http({
        url: API_URL + '/mobile-user-book-trip.json',
        method: 'POST',
        data: { p: getToken(), trip_id: trip_id, stripeToken: stripeToken, stripeEmail: stripeEmail }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    deleteTrip: function(trip_confirmation_id, callback) {
      $http({
        url: API_URL + '/mobile-trip-confirmation.json',
        method: 'DELETE',
        params: { p: getToken(), trip_confirmation_id: trip_confirmation_id }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('User', function($resource) {
	return $resource(API_URL + "/users/:id.json", { id: '@id' }, {
		index: { method: 'GET', isArray: true, responseType: 'json'},
    query: { method: 'GET', responseType: 'json' }
	});
})

.factory('UserService', function($http) {
  var token = window.localStorage['authToken'];
  var userId = window.localStorage['user_id'];
  var getToken = function() {
    return window.localStorage['authToken'];
  };

  var firebaseCallback;
  var registeredPush = false;

  var methods = {
    activate: function(token, email, callback) {
      $http({
        url: API_URL + '/mobile-activate.json',
        method: "GET",
        params: {activation_code: token, email: email}
      }).success(function(response) {
        callback(null, response);
      }).error(function(error) {
        callback(error);
      });
    },
    getUsers: function(callback) {
      $http({
        url: API_URL + '/mobile-users.json',
        method: "GET",
        params: {p: getToken()}
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    signi9Form: function(name, callback) {
      $http({
        url: API_URL + '/mobile-signi9Form.json',
        method: "POST",
        data: {
          p: getToken(),
          name: name
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      })
    },

    getUser: function(id, callback) {
      $http({
        url: API_URL + '/mobile-user.json',
        method: "GET",
        params: {p: getToken(), id: id}
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },
    invite: function(emails, reinvite, callback) {
      $http({
        url: API_URL + '/mobile-invite-friends.json',
        method: "POST",
        data: {p: getToken(), 'emails': emails, reinvite: reinvite ? 1 : undefined}
      }).success(function(response) {
        callback(null, response);
      }).error(function(error) {
        callback(error);
      });
    },
    getMe: function(callback) {
      var userId = window.localStorage['user_id'];
      if (!userId) return callback('Not logged in');

      $http({
        url: API_URL + '/mobile-user.json',
        method: "GET",
        params: {p: getToken(), id: userId}
      }).success(function(response) {
        callback(null, response);
      }).error(function(error) {
        callback(error);
      });
    },
    // UNCOMMENT BEFORE LAUNCH
    registerDeviceToken: function(callback) {
      window.FirebasePlugin.getToken(function(fcmToken) {
          // save this server-side and use it to push notifications to this device
        console.log(fcmToken);
        localStorage.setItem('fcmToken', fcmToken);
        $http({
          url: API_URL + '/mobile-register-device.json',
          method: "POST",
          data: {
            p: getToken(),
            device_type: device.platform.toLowerCase(),
            device_os: device.platform + " " + device.version,
            device_token: fcmToken
          }
        }).success(function(response) {
          callback(null, response);
        }).error(function(error) {
          callback(error);
        });

      }, function(error) {
        console.error(error);
      });
    },
    removeDeviceToken: function(callback) {
      var fcmToken = window.localStorage['fcmToken'];
      $http({
        url: API_URL + '/mobile-delete-device.json',
        method: "DELETE",
        params: {
          p: getToken(),
          device_token: fcmToken
        },
        data: {
          p: getToken(),
          device_token: fcmToken
        }
      }).success(function(response) {
        callback(null, response);
      }).error(function(error) {
        callback(error);
      });
    },
    onNotification: function(callback) {
      firebaseCallback = callback;

      if (registeredPush) return;

      registeredPush = true;
      console.log('registeredPush');
      window.FirebasePlugin.onNotificationOpen(function(notification) {
        console.log(notification);
        if (firebaseCallback) firebaseCallback(null, notification);
      }, function(error) {
        console.error(error);
        if (firebaseCallback) firebaseCallback(error);
      });
    }
  }

  return methods;
})
.factory('MiscService', function($http) {
  var token = window.localStorage['authToken'];

  var methods = {
    getHomeImages: function(callback) {
      $http({
        url: API_URL + '/mobile-photo-settings.json',
        method: "GET",
        params: {p: getToken()}
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('UserNewService', function($http) {
  var methods = {
    signupUser: function(firstName, lastName, email, password, passwordConfirmation, age, waiver_signature, tos, location, callback) {
      $http({
        url: API_URL + "/mobile-create.json",
        method: "POST",
        data: { user: {
            first_name: firstName, last_name: lastName, email: email, password: password,
            password_confirmation: passwordConfirmation, age: age, location: location,
            waiver_signature: waiver_signature, terms_of_service: tos, location: location
          }
        }
      }).then(
      function(response) {
        callback(response);
      },
      function(error) {
        callback(error);
      })
    }
  }
  return methods;
})

.factory('LoginService', function($http) {
  var methods = {
    loginUser: function(email, password, location, callback) {
      $http({
        url: API_URL + '/mobile-login.json',
        method: 'POST',
        data: { email: email, password: password, location: location }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    }
  }
  return methods;
})

.factory('ConversationService', function($http, $q) {
  var token = window.localStorage['authToken'];
  var methods = {
    index: function(callback) {
      $http({
        url: API_URL + '/message-mobile-user-index.json',
        method: "GET",
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    show: function(id, callback) {
      $http({
        url: API_URL + '/mesage-mobile-user-show/' + id + '.json',
        method: 'GET',
        params: { p: getToken(), id: id }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },

    reply: function(message, conversationId, callback) {
      $http({
        url: API_URL + '/message-mobile-user-reply.json',
        method: 'POST',
        data: { p: getToken(), conversation_id: conversationId, message: message }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    deleteConversation: function(conversationId, callback) {
      $http({
        url: API_URL + '/message-mobile-user-destroy.json',
        method: 'DELETE',
        params: { p: getToken(), conversation_id: conversationId }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('UserProfileService', function($http, $q) {
  var token = window.localStorage['authToken'];
  var methods = {
    getAbout: function(callback) {
      $http({
        url: API_URL + '/mobile-user-about.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(null, response);
      }).error(function(error) {
        callback(error);
      });
    },

    postAbout: function(firstName, lastName, paypalEmail, currentLocation, experienceLevel, climbingType, age, description, callback) {
      $http({
        url: API_URL + '/mobile-user-p-about.json',
        method: 'POST',
        data: { p: getToken(), user: {
          first_name: firstName, last_name: lastName, paypal_email: paypalEmail,
          current_city: currentLocation, experience_level: experienceLevel, climbing_type:
          climbingType, age: age, description: description }
        }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    userHost: function(callback) {
      $http({
        url: API_URL + '/mobile-user-host.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('UserPhoneVerificationService', function($http, $q) {
  var token = window.localStorage['authToken'];

  var methods = {
    getVerificationCode: function(phoneNumber, callback) {
      $http({
        url: API_URL + '/mobile-user-phone-number.json',
        method: 'GET',
        params: { p: getToken(), phone_number: phoneNumber }
      }).success(function(response) {
        console.log("verification success");
        callback(response);
      }).error(function(error) {
        console.log("verification error");
        callback(error);
      });
    },

    verifyPhoneNumber: function(code, callback) {
      $http({
        url: API_URL + '/mobile-user-phone-verification.json',
        method: 'POST',
        data: { p: getToken(), v_code: code }
      }).success(function(response) {
        console.log("from verify phone#");
        callback(response);
      }).error(function(error) {
        console.log("verify phone# error");
        callback(error);
      });
    }
  }
  return methods;
})

.factory('UserTripService', function($http, $q) {
  var token = window.localStorage['authToken'];

  var incrementDate = function (date, amount) {
    var tmpDate = new Date(date);
    tmpDate.setDate(tmpDate.getDate() + amount)
    return tmpDate;
  };

  var methods = {
    // user.trips (hosted trips)
    getAllTrips: function(callback) {
      $http({
        url: API_URL + '/mobile-user-trips.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    // trips went on as climber
    getClimbingTrips: function(callback) {
      $http({
        url: API_URL + '/mobile-user-climbing-trips.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    },

    createTrip: function(tripId, title, startDate, endDate, startTime, endTime, pickup_address, climbingSpot, price, before_price, available_spots, languages_spoken, climbing_type, experience_level, notes, images, deleteImages, callback) {
      var formData = new FormData();
      formData.append('p', token);
      formData.append('title', title);
      formData.append('start_date', startDate);
      formData.append('end_date', endDate);
      formData.append('start_time', startTime);
      formData.append('end_time', endTime);
      formData.append('pickup_address', pickup_address);
      formData.append('climbing_spot', climbingSpot);
      formData.append('price', price);
      formData.append('before_price', before_price);
      formData.append('available_spots', available_spots);
      formData.append('climbing_type', climbing_type);
      formData.append('experience_level', experience_level);
      formData.append('notes', notes);
      formData.append('languages_spoken', languages_spoken);

      if (images && Array.isArray(images) && images.length > 0) {
        for (var i = 0; i < images.length; i++) {
          var image = images[i];

          formData.append('file[]', (image.data));
        }
      }
      if (deleteImages && Array.isArray(deleteImages) && deleteImages.length > 0) {
        for (var i = 0; i < deleteImages.length; i++) {
          formData.append('deleted_file_ids[]', deleteImages[i]);
        }
      }

      $http({
          url: API_URL + ( tripId ? '/mobile-user-trips/'+tripId+'.json' : '/mobile-user-trips.json'),
          method: tripId ? 'PUT' : 'POST',
          data: formData,
          //assign content-type as undefined, the browser
          //will assign the correct boundary for us
          headers: { 'Content-Type': undefined},
          //prevents serializing payload.  don't do it.
          transformRequest: angular.identity
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });

      // $http({
      //   url: API_URL + '/mobile-user-trips.json',
      //   method: 'POST',
      //   data: { p: getToken(), title: title, start_date: startDate, start_time: startTime, end_time: endTime,
      //   location: location, climbing_spot: climbingSpot, price: price, climbing_type: climbing_type,
      //   experience_level: experience_level, notes: notes }
      // }).success(function(response) {
      //   callback(response);
      // }).error(function(error) {
      //   callback(error);
      // });
    },

    deleteTrip: function(trip_id, callback) {
      $http({
        url: 'delete-url.json',
        method: 'DELETE',
        data: { p: getToken(), trip_id: trip_id }
      }).success(function(response) {
        callback(response)
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('UserReviewService', function($http) {
  var token = window.localStorage['authToken'];

  var methods = {
    getReviews: function(callback) {
      $http({
        url: API_URL + '/mobile-user-reviews.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('AmgaService', function($http) {
  var token = window.localStorage['authToken'];

  var methods = {
    get: function(callback) {
      $http({
        url: API_URL + '/mobile-user-certificate.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },

    upload: function(base64, callback) {
      $http({
        url: API_URL + '/mobile-user-certificate.json',
        method: 'POST',
        data: { p: getToken(), image_file: base64 }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },

    destroy: function(image_id, callback) {
      $http({
        url: API_URL + '/mobile-user-certificate.json',
        method: 'DELETE',
        params: { p: getToken(), image_id: image_id }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})


.factory('UserPictureService', function($http) {
  var token = window.localStorage['authToken'];

  var methods = {
    getAll: function(callback) {
      $http({
        url: API_URL + '/mobile-user-pictures.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },

    upload: function(base64, callback) {
      $http({
        url: API_URL + '/mobile-user-picture.json',
        method: 'POST',
        data: { p: getToken(), image_file: base64 }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },

    uhv_upload: function(base64, callback) {
      $http({
        url: API_URL + '/mobile-user-host-verification.json',
        method: 'POST',
        data: { p: getToken(), image_file: base64 }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },

    destroy: function(image_id, callback) {
      $http({
        url: API_URL + '/mobile-user-picture.json',
        method: 'DELETE',
        params: { p: getToken(), image_id: image_id }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      });
    }
  }
  return methods;
})

.factory('ImageService', function($ionicPopup, $ionicLoading) {
  var toDataUrl = function(url, callback, onerror) {
    var xhr = new XMLHttpRequest();
    xhr.onload = function() {
      var reader = new FileReader();
      reader.onloadend = function() {
        callback(reader.result);
      }
      reader.onerror = function(event) {
        console.log(event);
        onerror();
      }
      reader.readAsDataURL(xhr.response);
    };
    xhr.onerror = function(event) {
      console.log(event);
      onerror();
    };

    xhr.open('GET', url);
    xhr.responseType = 'blob';
    xhr.send();
  };

  var methods = {
    getImage: function(onsuccess, onerror) {
      ionic.Platform.ready(function(){
        $ionicLoading.show({
          content: 'Loading...',
          showBackdrop: false
        });
        navigator.camera.getPicture(function(file) {
          return toDataUrl(file, function(base64Img) {
            if (onsuccess && typeof onsuccess == 'function') onsuccess(base64Img);
            $ionicLoading.hide();
          }, function(error) {
            if (onerror && typeof onerror == 'function') onerror(error);
            $ionicLoading.hide();
          })
        }, function(error) {
          var scope = {message: "Error: Failed to Attach Image \n" + error};
          $ionicLoading.hide();

          var alertPopup = $ionicPopup.alert({
            title: 'User Photos',
            templateUrl: 'templates/modals/success_or_error.html',
            scope: scope
          });
          if (onerror && typeof onerror == 'function') onerror(error);
        }, {
          quality: 20,
          targetWidth: 1024,
          targetHeight: 1024,
          correctOrientation: true,
          destinationType: Camera.DestinationType.FILE_URI,
          sourceType: Camera.PictureSourceType.PHOTOLIBRARY
        });
      });
    }
  }
  return methods;
})

.factory('StripeCharge', function($q, $http, StripeCheckout) {

  /*
  This service connects to a seperate node app to make mobile payments work
  via stripe. repo is on github: https://github.com/jnewman12/node-stripe-api
  */

  var self = this;
  var SERVER_SIDE_URL = "https://stormy-waters-18197.herokuapp.com";

  self.chargeUser = function(stripeToken, ProductMeta) {
    var qCharge = $q.defer();

    var chargeUrl = API_URL + "/charge";
    var curlData = {
      stripeCurrency:         "usd",
      stripeAmount:           Math.floor(ProductMeta.priceUSD*100),
      stripeSource:           stripeToken,
      // need to add trip title as the description
      stripeDescription:      "Climblife app: " + ProductMeta.title
    };
    $http.post(chargeUrl, curlData)
    .success(
      function(StripeInvoiceData){
        qCharge.resolve(StripeInvoiceData);
        // you can store the StripeInvoiceData for your own administration
      }
    )
    .error(
      function(error){
        console.log(error)
        qCharge.reject(error);
      }
    );
    return qCharge.promise;
  };


  /**
   * Get a stripe token through the checkout handler
   */
  self.getStripeToken = function(ProductMeta) {
    var qToken = $q.defer();

    var handlerOptions = {
      name: ProductMeta.title,
      description: ProductMeta.description,
      amount: Math.floor(ProductMeta.priceUSD*100),
      image: ProductMeta.image,
    };

    var handler = StripeCheckout.configure({
      name: ProductMeta.title,
      token: function(token, args) {
        //console.log(token.id)
      }
    })

    handler.open(handlerOptions).then(
      function(result) {
        var stripeToken = result[0].id,
          stripeEmail = result[0].email;
        if(stripeToken != undefined && stripeToken != null && stripeToken != "") {
            //console.log("handler success - defined")
            qToken.resolve({stripeToken: stripeToken, stripeEmail: stripeEmail});
        } else {
            //console.log("handler success - undefined")
            qToken.reject("ERROR_STRIPETOKEN_UNDEFINED");
        }
      }, function(error) {
        if(error == undefined) {
          qToken.reject("ERROR_CANCEL");
        } else {
          qToken.reject(error);
        }
      }
    );
    return qToken.promise;
  };


  return self;
})

.factory('InstantClimbService', function($http) {
  var methods = {
    // all current instant climbs
    getAll: function(callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },
    // view specific instant climb
    show: function(instantClimbId, callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs/' + instantClimbId + '.json',
        method: 'GET',
        params: { p: getToken(), instant_climb_id: instantClimbId }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },
    // user who made instant climb can edit
    edit: function(id, startDate, endDate, pickup_address, available_spots, languages_spoken, climbing_type, experience_level, callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs/' + id + '.json',
        method: 'PUT',
        data: {
          p: getToken(),
          start_date: startDate, 
          end_date: endDate, 
          pickup_address: pickup_address, 
          available_spots: available_spots, 
          languages_spoken: languages_spoken,
          climbing_type: climbing_type, 
          experience_level: experience_level
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      })
    },
    // for user to create an instant climb
    create: function(startDate, endDate, pickup_address, available_spots, languages_spoken, climbing_type, experience_level, notes, callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs.json',
        method: 'POST',
        data: {
          p: getToken(),
          start_date: startDate, 
          end_date: endDate, 
          pickup_address: pickup_address, 
          available_spots: available_spots, 
          languages_spoken: languages_spoken,
          climbing_type: climbing_type, 
          experience_level: experience_level,
          notes: notes
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      })
    },
    // for user who created an instant climb to destroy
    destroy: function(instantClimbId, callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs/' + instantClimbId + '.json',
        method: 'DELETE',
        params: { p: getToken(), instant_climb_id: instantClimbId }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },
    // to see all instant climbs a user (host) has bid on
    userBids: function(callback) {
      $http({
        url: API_URL + '/mobile-instant-climb-bids.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(response);
      })
    },
    getAllForUser: function(callback) {
      $http({
        url: API_URL + '/mobile-user-instant-climbs.json',
        method: 'GET',
        params: { p: getToken() }
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(response);
      })
    }
  }

  return methods;
})

.factory('InstantClimbBidService', function($http) {
  var methods = {
    // get all bids for certain climb
    getAll: function(instantClimbId, callback) {

    },
    create: function(instantClimbId, price, notes, callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs/' + instantClimbId + '/bids.json',
        method: 'POST',
        data: {
          p: getToken(),
          price: price,
          notes: notes
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      })
    },
    destroy: function(instantClimbId, bidId, callback) {

    },
    // bids a user has made for instant climbs?
    userBids: function(token, callback) {

    },
    // a climber reject a bid
    rejectBid: function(instantClimbId, bidId, callback) {
      $http({
        url: API_URL + '/mobile-instant-climbs/' + instantClimbId + '/bids/' + bidId + '/reject.json',
        method: 'DELETE',
        params: {
          p: getToken()
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      })
    },
    // for viewing bid before it's accepted to grab instant climb and selected bid price
    viewSelectedBid: function(instantClimbId, bidId, callback) {
      $http({
        url: API_URL + '/mobile-instant-climb-bid/' + instantClimbId + '/bids/' + bidId + '.json',
        method: 'GET',
        params: {
          p: getToken()
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      })
    },
    // to mark instant climb + bid as accepted and charge card
    bookInstantClimb: function(instantClimbId, bidId, stripeToken, stripeEmail, callback) {
      $http({
        url: API_URL + '/mobile-instant-climb-book-trip.json',
        method: 'POST',
        data: {
          p: getToken(),
          instant_climb_id: instantClimbId,
          bid_id: bidId,
          stripeToken: stripeToken,
          stripeEmail: stripeEmail
        }
      }).success(function(response) {
        callback(response);
      }).error(function(response) {
        callback(response);
      });
    }
  }
  return methods;
})

.factory('IpAddressService', function($http) {
  var methods = {
    getIpAddress: function(callback) {
      $http({
        url: 'https://api6.ipify.org?format=json',
        method: 'GET'
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    },
    getLocationFromIp: function(ip_address, callback) {
      $http({
        url: 'https://ipapi.co/' + ip_address + '/json/',
        method: 'GET'
      }).success(function(response) {
        callback(response);
      }).error(function(error) {
        callback(error);
      })
    }
  };
  return methods;
})

// 500 error checker, injected into app.js
// should do something w/ 400 errors as well
.factory('errorInterceptor', ['$q', '$rootScope', '$location', '$injector',
  function ($q, $rootScope, $location, $injector) {
    return {
      request: function (config) {
        return config || $q.when(config);
      },
      requestError: function(request){
        return $q.reject(request);
      },
      response: function (response) {
        if (response.data && (typeof response.data == 'object') && response.data.code == 401) {
          console.log(response.data);
          var $state = $injector.get('$state');
          localStorage.removeItem('user_id');
          localStorage.removeItem('authToken');
          $state.go('main.login', {}, {reload: true});
          return $q.reject(response);
        }
        return response || $q.when(response);
      },
      responseError: function (response) {
        console.log(response);
        if (response && response.status >= 500) {
          var $state = $injector.get('$state');
          var $ionicPopup = $injector.get('$ionicPopup');
          var $ionicHistory = $injector.get('$ionicHistory');

          var alertPopup = $ionicPopup.alert({
            title: 'Server Error',
            templateUrl: 'templates/modals/server_error.html'
          });

          alertPopup.then(function(res) {
            $ionicHistory.nextViewOptions({
              historyRoot: true
            });

            $state.go('main.index');
            // $location.path('#/main/index');
          });
        }
        return $q.reject(response);
      }
    };
}])
// services end
;


